==> fake_bpy_module_2.78-20200218-py3-none-any.whl: bpy/ops/__init__.py <==
import sys
import typing
from . import mball
from . import poselib
from . import paint
from . import nla
from . import view2d
from . import gpencil
from . import armature
from . import wm
from . import surface
from . import ptcache
from . import curve
from . import image
from . import boid
from . import sequencer
from . import time
from . import logic
from . import paintcurve
from . import sound
from . import mask
from . import clip
from . import export_anim
from . import marker
from . import scene
from . import import_scene
from . import object
from . import material
from . import brush
from . import particle
from . import cloth
from . import sketch
from . import mesh
from . import uv
from . import info
from . import script
from . import render
from . import pose
from . import buttons
from . import ed
from . import graph
from . import fluid
from . import text
from . import group
from . import camera
from . import export_scene
from . import dpaint
from . import export_mesh
from . import safe_areas
from . import lamp
from . import ui
from . import constraint
from . import texture
from . import transform
from . import lattice
from . import import_curve
from . import cachefile
from . import import_mesh
from . import rigidbody
from . import sculpt
from . import screen
from . import view3d
from . import outliner
from . import palette
from . import anim
from . import file
from . import font
from . import world
from . import cycles
from . import node
from . import console
from . import action
from . import import_anim

==> fake_bpy_module_2.78-20200428-py3-none-any.whl: bpy/ops/__init__.py <==
import sys
import typing
from . import constraint
from . import gpencil
from . import lamp
from . import import_mesh
from . import group
from . import node
from . import mask
from . import ui
from . import particle
from . import brush
from . import mesh
from . import palette
from . import ed
from . import text
from . import script
from . import info
from . import camera
from . import scene
from . import console
from . import import_curve
from . import image
from . import import_anim
from . import pose
from . import font
from . import paint
from . import safe_areas
from . import outliner
from . import render
from . import export_scene
from . import boid
from . import marker
from . import fluid
from . import sound
from . import nla
from . import time
from . import world
from . import paintcurve
from . import object
from . import file
from . import view2d
from . import screen
from . import cachefile
from . import import_scene
from . import wm
from . import export_mesh
from . import dpaint
from . import uv
from . import clip
from . import export_anim
from . import surface
from . import sequencer
from . import armature
from . import lattice
from . import logic
from . import graph
from . import sketch
from . import sculpt
from . import anim
from . import material
from . import buttons
from . import cycles
from . import transform
from . import poselib
from . import action
from . import texture
from . import view3d
from . import curve
from . import cloth
from . import mball
from . import ptcache
from . import rigidbody


class BPyOps:
    pass


class BPyOpsSubMod:
    pass


class BPyOpsSubModOp:
    def get_instance(self):
        '''

        '''
        pass

    def get_rna(self):
        '''

        '''
        pass

    def idname(self):
        '''

        '''
        pass

    def idname_py(self):
        '''

        '''
        pass

    def poll(self, args):
        '''

        '''
        pass
